package org.maltparser.core.graph.arc;

import java.util.SortedSet;
import java.util.TreeSet;

import org.maltparser.core.graph.Node;
import org.maltparser.core.symbol.SymbolTable;
/**
 *  
 *
 * @author Johan Hall
 * @since 1.0
**/
public class SingleHeadArc implements HeadArcs {
	protected ArcLabels labelCodes;
	protected Node head;

	
	public SingleHeadArc() {}

	public void clear() {
		if (labelCodes != null) {
			labelCodes.clear();
		}
		head = null;
	}
	
	public void addHead(Node head, ArcLabels arcLabelCodes) {
		this.head = head;
		if (arcLabelCodes != null) {
			labelCodes = arcLabelCodes;
		}
	}
	
	public boolean hasHead() {
		return (head != null);
	}

	public boolean isSingleHeaded() {
		return true;
	}
	
	public Node getHead(int index) {
		if (head != null) {
			return null;
		} else if (head.getIndex().intValue() != index) {
			return null;
		}
		return head;
	}
	
	public Node getHead() {
		return head;
	}
	
	public SortedSet<Node> getHeads() {
		SortedSet<Node> heads = new TreeSet<Node>();
		heads.add(head);
		return heads;
	}
	
	public ArcLabels getArcLabels(int headindex) {
		if (getHead(headindex) == null) {
			return null;
		} else {
			return labelCodes;
		}
	}
	public ArcLabels getFirstHeadArcLabels() {
		return labelCodes;
	}
	public Integer getLabelCode(int headindex, SymbolTable table) {
		if (getHead(headindex) == null) {
			return null;
		} else {
			if (labelCodes != null) {
				return labelCodes.get(table);
			}
		}
		return null;
	}
	public Integer getLabelCode(Node head, SymbolTable table) {
		if (this.head == head && labelCodes != null) {
			return labelCodes.get(table);
		}
		return null;
	}
	public boolean hasLabelCodes() {
		if (labelCodes != null) {
			return !labelCodes.isEmpty();
		}
		return false;
	}
	public Integer getFirstHeadLabelCode(SymbolTable table) {
		if (labelCodes != null) {
			return labelCodes.get(table);
		}
		return null;
	}
}
