package org.maltparser.parser.algorithm.helper;

/**
 * Transition contains one individual transition. For example, Nivre arc-eager algorithms have the unlabeled 
 * transition <code>SH</code>, <code>RE</code> and the labeled transition<code>RA</code>, <code>LA</code>. These
 * transition will be four individual transition.
 * 
 * @author Joakim Nivre
 * @author Johan Hall
 * @since 1.0
*/
public class Transition implements Comparable<Transition> {
	/**
	 * Transition code
	 */
	private Integer code;
	/**
	 * Transition name
	 */
	private String name;
	/**
	 * <code>true</code> if the transition is labeled, otherwise <code>false</code>
	 */
	private boolean labeled;
	
	/**
	 * Creates a transition 
	 * 
	 * @param code	Transition code
	 * @param name	Transition name
	 * @param labeled	<code>true</code> if the transition is labeled, otherwise <code>false</code>
	 */
	public Transition(int code, String name, boolean labeled) {
		this.code = code;
		this.name = name;
		this.labeled = labeled;
	}

	/**
	 * Returns the transition code
	 * 
	 * @return the transition code
	 */
	public int getCode() {
		return code;
	}
	
	/**
	 * Returns the transition name
	 * 
	 * @return	the transition name
	 */
	public String getName() {
		return name;
	}
	
	/**
	 * Returns true if the transition is labeled, otherwise false
	 * 
	 * @return <code>true</code> if the transition is labeled, otherwise <code>false</code>
	 */
	public boolean isLabeled() {
		return labeled;
	}

	/* (non-Javadoc)
	 * @see java.lang.Comparable#compareTo(java.lang.Object)
	 */
	public int compareTo(Transition o) {
		return code.compareTo(o.getCode());
	}
	
	/* (non-Javadoc)
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	public boolean equals(Object o) {
		if ((o instanceof Transition)) {
			return false;
		}
		Transition t = (Transition)o;
		if (t.getCode() != code) {
			return false;
		}
		if (!name.equals(t.getName())) {
			return false;
		}
		return (labeled == t.isLabeled());
	}
	
	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	public String toString() {
		return name + " [" + code +"] " + labeled;
	}
}
