package org.maltparser.parser.guide.classtable;

import org.maltparser.core.exception.MaltChainedException;
import org.maltparser.ml.KBestList;
import org.maltparser.parser.algorithm.helper.ParserAction;

/**


@author Johan Hall
@since 1.0
 */
public abstract class ClassTable {
	protected ParserAction parserAction;
	protected int currentClassCode;
	protected String currentClassString;
	protected KBestList kBestList;
	
	public ClassTable(ParserAction parserAction, int kbest) {
		setParserAction(parserAction);
		setCurrentClassCode(0);
		kBestList = new KBestList(kbest);
	}

	public int getCurrentClassCode() {
		return currentClassCode;
	}
	
	protected void setCurrentClassCode(int currentClassCode) {
		this.currentClassCode = currentClassCode;
	}

	public String getCurrentClassString() {
		return currentClassString;
	}

	protected void setCurrentClassString(String currentClassString) {
		this.currentClassString = currentClassString;
	}

	public ParserAction getParserAction() {
		return parserAction;
	}

	protected void setParserAction(ParserAction parserAction) {
		this.parserAction = parserAction;
	}	
	
	public KBestList getEmptyKBestList() {
		kBestList.clear();
		return kBestList;
	}
	
	public abstract boolean updateClassCode() throws MaltChainedException;
	public abstract ParserAction updateParserActionWithFirstKBest() throws MaltChainedException;
	public abstract ParserAction updateParserActionWithNextKBest() throws MaltChainedException;
	public abstract void setValue(Integer value) throws MaltChainedException;
	public abstract void setValue(String value) throws MaltChainedException;
	public abstract String getTableName() throws MaltChainedException;
}
